﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using HeuristicLab.Core;

namespace HeuristicLab.Encodings.ConditionActionEncoding {
  /// <summary>
  /// IMatching is used in dictinoaries, therefore the methods "Equals" and "GetHashCode" have to be overriden
  /// IEquatable<IMatching> should be implemented as well.
  /// 
  /// This also helps to implement macroclassifiers later on
  /// </summary>
  public interface IClassifier : IItem, IEquatable<IClassifier> {
    IClassifier Condition { get; }
    IClassifier Action { get; }
    bool MatchCondition(IClassifier target);
    bool MatchAction(IClassifier target);
    bool IsMoreGeneral(IClassifier target);

    //to use IMatching as key in a dictionary, Equals and GetHashCode have to be override. 
    //Also IEquatable<Class> should be implemented.
    bool Equals(object obj);
    int GetHashCode();
  }
}
